@@ -4,8 +4,7 @@ namespace PhpParser\ErrorHandler;
 
 use PhpParser\Error;
 
-class ThrowingTest extends \PHPUnit\Framework\TestCase
-{
+class ThrowingTest extends \PHPUnit\Framework\TestCase {
     public function testHandleError() {
         $this->expectException(Error::class);
         $this->expectExceptionMessage('Test');
