@@ -6,11 +6,9 @@ namespace PhpParser\Node\Scalar;
 use PhpParser\Node\Stmt\Echo_;
 use PhpParser\ParserFactory;
 
-class DNumberTest extends \PHPUnit\Framework\TestCase
-{
-    public function testRawValue()
-    {
-        $parser = (new ParserFactory())->create(ParserFactory::PREFER_PHP7);
+class DNumberTest extends \PHPUnit\Framework\TestCase {
+    public function testRawValue() {
+        $parser = (new ParserFactory())->createForNewestSupportedVersion();
         $nodes = $parser->parse('<?php echo 1_234.56;');
 
         $echo = $nodes[0];
@@ -18,9 +16,9 @@ class DNumberTest extends \PHPUnit\Framework\TestCase
 
         /** @var Echo_ $echo */
         $lLumber = $echo->exprs[0];
-        $this->assertInstanceOf(DNumber::class, $lLumber);
+        $this->assertInstanceOf(Float_::class, $lLumber);
 
-        /** @var DNumber $dnumber */
+        /** @var Float_ $dnumber */
         $this->assertSame(1234.56, $lLumber->value);
         $this->assertSame('1_234.56', $lLumber->getAttribute('rawValue'));
     }
