@@ -2,8 +2,7 @@
 
 namespace PhpParser;
 
-class DummyNode extends NodeAbstract
-{
+class DummyNode extends NodeAbstract {
     public $subNode1;
     public $subNode2;
     public $notSubNode;
@@ -15,18 +14,17 @@ class DummyNode extends NodeAbstract
         $this->notSubNode = $notSubNode;
     }
 
-    public function getSubNodeNames() : array {
+    public function getSubNodeNames(): array {
         return ['subNode1', 'subNode2'];
     }
 
     // This method is only overwritten because the node is located in an unusual namespace
-    public function getType() : string {
+    public function getType(): string {
         return 'Dummy';
     }
 }
 
-class NodeAbstractTest extends \PHPUnit\Framework\TestCase
-{
+class NodeAbstractTest extends \PHPUnit\Framework\TestCase {
     public function provideNodes() {
         $attributes = [
             'startLine' => 10,
@@ -65,9 +63,9 @@ class NodeAbstractTest extends \PHPUnit\Framework\TestCase
         $this->assertSame('/** doc comment */', $node->getDocComment()->getText());
         $this->assertSame('value1', $node->subNode1);
         $this->assertSame('value2', $node->subNode2);
-        $this->assertObjectHasAttribute('subNode1', $node);
-        $this->assertObjectHasAttribute('subNode2', $node);
-        $this->assertObjectNotHasAttribute('subNode3', $node);
+        $this->assertTrue(isset($node->subNode1));
+        $this->assertTrue(isset($node->subNode2));
+        $this->assertTrue(!isset($node->subNode3));
         $this->assertSame($attributes, $node->getAttributes());
         $this->assertSame($attributes['comments'], $node->getComments());
 
@@ -127,7 +125,7 @@ class NodeAbstractTest extends \PHPUnit\Framework\TestCase
         $this->assertSame('newValue', $node->subNode1);
 
         // indirect modification
-        $subNode =& $node->subNode1;
+        $subNode = &$node->subNode1;
         $subNode = 'newNewValue';
         $this->assertSame('newNewValue', $node->subNode1);
 
@@ -154,7 +152,7 @@ class NodeAbstractTest extends \PHPUnit\Framework\TestCase
                 $this->assertSame('notSubNode', $key);
                 $this->assertSame('value3', $value);
             } else {
-                throw new \Exception;
+                throw new \Exception();
             }
             $i++;
         }
@@ -222,7 +220,11 @@ PHP;
             "name": "functionName",
             "attributes": {
                 "startLine": 4,
-                "endLine": 4
+                "startTokenPos": 7,
+                "startFilePos": 45,
+                "endLine": 4,
+                "endTokenPos": 7,
+                "endFilePos": 56
             }
         },
         "params": [
@@ -236,15 +238,23 @@ PHP;
                     "name": "a",
                     "attributes": {
                         "startLine": 4,
-                        "endLine": 4
+                        "startTokenPos": 10,
+                        "startFilePos": 59,
+                        "endLine": 4,
+                        "endTokenPos": 10,
+                        "endFilePos": 60
                     }
                 },
                 "default": {
-                    "nodeType": "Scalar_LNumber",
+                    "nodeType": "Scalar_Int",
                     "value": 0,
                     "attributes": {
                         "startLine": 4,
+                        "startTokenPos": 14,
+                        "startFilePos": 64,
                         "endLine": 4,
+                        "endTokenPos": 14,
+                        "endFilePos": 64,
                         "rawValue": "0",
                         "kind": 10
                     }
@@ -253,7 +263,11 @@ PHP;
                 "attrGroups": [],
                 "attributes": {
                     "startLine": 4,
-                    "endLine": 4
+                    "startTokenPos": 9,
+                    "startFilePos": 58,
+                    "endLine": 4,
+                    "endTokenPos": 14,
+                    "endFilePos": 64
                 }
             },
             {
@@ -266,15 +280,23 @@ PHP;
                     "name": "b",
                     "attributes": {
                         "startLine": 4,
-                        "endLine": 4
+                        "startTokenPos": 17,
+                        "startFilePos": 67,
+                        "endLine": 4,
+                        "endTokenPos": 17,
+                        "endFilePos": 68
                     }
                 },
                 "default": {
-                    "nodeType": "Scalar_DNumber",
+                    "nodeType": "Scalar_Float",
                     "value": 1,
                     "attributes": {
                         "startLine": 4,
+                        "startTokenPos": 21,
+                        "startFilePos": 72,
                         "endLine": 4,
+                        "endTokenPos": 21,
+                        "endFilePos": 74,
                         "rawValue": "1.0"
                     }
                 },
@@ -282,7 +304,11 @@ PHP;
                 "attrGroups": [],
                 "attributes": {
                     "startLine": 4,
-                    "endLine": 4
+                    "startTokenPos": 17,
+                    "startFilePos": 67,
+                    "endLine": 4,
+                    "endTokenPos": 21,
+                    "endFilePos": 74
                 }
             }
         ],
@@ -296,7 +322,11 @@ PHP;
                         "value": "Foo",
                         "attributes": {
                             "startLine": 5,
+                            "startTokenPos": 28,
+                            "startFilePos": 88,
                             "endLine": 5,
+                            "endTokenPos": 28,
+                            "endFilePos": 92,
                             "kind": 1,
                             "rawValue": "'Foo'"
                         }
@@ -304,14 +334,22 @@ PHP;
                 ],
                 "attributes": {
                     "startLine": 5,
-                    "endLine": 5
+                    "startTokenPos": 26,
+                    "startFilePos": 83,
+                    "endLine": 5,
+                    "endTokenPos": 29,
+                    "endFilePos": 93
                 }
             }
         ],
         "attrGroups": [],
-        "namespacedName": null,
         "attributes": {
             "startLine": 4,
+            "startTokenPos": 5,
+            "startFilePos": 36,
+            "endLine": 6,
+            "endTokenPos": 31,
+            "endFilePos": 95,
             "comments": [
                 {
                     "nodeType": "Comment",
@@ -333,8 +371,7 @@ PHP;
                     "endFilePos": 34,
                     "endTokenPos": 3
                 }
-            ],
-            "endLine": 6
+            ]
         }
     }
 ]
@@ -345,6 +382,11 @@ JSON;
         "nodeType": "Stmt_Function",
         "attributes": {
             "startLine": 4,
+            "startTokenPos": 5,
+            "startFilePos": 36,
+            "endLine": 6,
+            "endTokenPos": 31,
+            "endFilePos": 95,
             "comments": [
                 {
                     "nodeType": "Comment",
@@ -366,15 +408,18 @@ JSON;
                     "endFilePos": 34,
                     "endTokenPos": 3
                 }
-            ],
-            "endLine": 6
+            ]
         },
         "byRef": false,
         "name": {
             "nodeType": "Identifier",
             "attributes": {
                 "startLine": 4,
-                "endLine": 4
+                "startTokenPos": 7,
+                "startFilePos": 45,
+                "endLine": 4,
+                "endTokenPos": 7,
+                "endFilePos": 56
             },
             "name": "functionName"
         },
@@ -383,7 +428,11 @@ JSON;
                 "nodeType": "Param",
                 "attributes": {
                     "startLine": 4,
-                    "endLine": 4
+                    "startTokenPos": 9,
+                    "startFilePos": 58,
+                    "endLine": 4,
+                    "endTokenPos": 14,
+                    "endFilePos": 64
                 },
                 "type": null,
                 "byRef": true,
@@ -392,15 +441,23 @@ JSON;
                     "nodeType": "Expr_Variable",
                     "attributes": {
                         "startLine": 4,
-                        "endLine": 4
+                        "startTokenPos": 10,
+                        "startFilePos": 59,
+                        "endLine": 4,
+                        "endTokenPos": 10,
+                        "endFilePos": 60
                     },
                     "name": "a"
                 },
                 "default": {
-                    "nodeType": "Scalar_LNumber",
+                    "nodeType": "Scalar_Int",
                     "attributes": {
                         "startLine": 4,
+                        "startTokenPos": 14,
+                        "startFilePos": 64,
                         "endLine": 4,
+                        "endTokenPos": 14,
+                        "endFilePos": 64,
                         "rawValue": "0",
                         "kind": 10
                     },
@@ -413,7 +470,11 @@ JSON;
                 "nodeType": "Param",
                 "attributes": {
                     "startLine": 4,
-                    "endLine": 4
+                    "startTokenPos": 17,
+                    "startFilePos": 67,
+                    "endLine": 4,
+                    "endTokenPos": 21,
+                    "endFilePos": 74
                 },
                 "type": null,
                 "byRef": false,
@@ -422,15 +483,23 @@ JSON;
                     "nodeType": "Expr_Variable",
                     "attributes": {
                         "startLine": 4,
-                        "endLine": 4
+                        "startTokenPos": 17,
+                        "startFilePos": 67,
+                        "endLine": 4,
+                        "endTokenPos": 17,
+                        "endFilePos": 68
                     },
                     "name": "b"
                 },
                 "default": {
-                    "nodeType": "Scalar_DNumber",
+                    "nodeType": "Scalar_Float",
                     "attributes": {
                         "startLine": 4,
+                        "startTokenPos": 21,
+                        "startFilePos": 72,
                         "endLine": 4,
+                        "endTokenPos": 21,
+                        "endFilePos": 74,
                         "rawValue": "1.0"
                     },
                     "value": 1
@@ -445,14 +514,22 @@ JSON;
                 "nodeType": "Stmt_Echo",
                 "attributes": {
                     "startLine": 5,
-                    "endLine": 5
+                    "startTokenPos": 26,
+                    "startFilePos": 83,
+                    "endLine": 5,
+                    "endTokenPos": 29,
+                    "endFilePos": 93
                 },
                 "exprs": [
                     {
                         "nodeType": "Scalar_String",
                         "attributes": {
                             "startLine": 5,
+                            "startTokenPos": 28,
+                            "startFilePos": 88,
                             "endLine": 5,
+                            "endTokenPos": 28,
+                            "endFilePos": 92,
                             "kind": 1,
                             "rawValue": "'Foo'"
                         },
@@ -461,8 +538,7 @@ JSON;
                 ]
             }
         ],
-        "attrGroups": [],
-        "namespacedName": null
+        "attrGroups": []
     }
 ]
 JSON;
