@@ -9,26 +9,24 @@ use PhpParser\NodeFinder;
 use PhpParser\NodeTraverser;
 use PhpParser\ParserFactory;
 
-final class NodeConnectingVisitorTest extends \PHPUnit\Framework\TestCase
-{
-    public function testConnectsNodeToItsParentNodeAndItsSiblingNodes()
-    {
-        $ast = (new ParserFactory)->create(ParserFactory::PREFER_PHP7)->parse(
+final class NodeConnectingVisitorTest extends \PHPUnit\Framework\TestCase {
+    public function testConnectsNodeToItsParentNodeAndItsSiblingNodes() {
+        $ast = (new ParserFactory())->createForNewestSupportedVersion()->parse(
             '<?php if (true) {} else {}'
         );
 
-        $traverser = new NodeTraverser;
+        $traverser = new NodeTraverser();
 
-        $traverser->addVisitor(new NodeConnectingVisitor);
+        $traverser->addVisitor(new NodeConnectingVisitor());
 
         $ast = $traverser->traverse($ast);
 
-        $node = (new NodeFinder)->findFirstInstanceof($ast, Else_::class);
+        $node = (new NodeFinder())->findFirstInstanceof($ast, Else_::class);
 
         $this->assertSame(If_::class, get_class($node->getAttribute('parent')));
         $this->assertSame(ConstFetch::class, get_class($node->getAttribute('previous')));
 
-        $node = (new NodeFinder)->findFirstInstanceof($ast, ConstFetch::class);
+        $node = (new NodeFinder())->findFirstInstanceof($ast, ConstFetch::class);
 
         $this->assertSame(Else_::class, get_class($node->getAttribute('next')));
     }
